@@ -1,8 +1,8 @@
 /*
   +----------------------------------------------------------------------+
-  | PHP Version 5, 7                                                     |
+  | PHP Version 5, 7, 8                                                  |
   +----------------------------------------------------------------------+
-  | Copyright (c) 1997-2018 The PHP Group                                |
+  | Copyright (c) 1997-2020 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -247,7 +247,11 @@ static php_stream_filter_ops lzf_decompress_ops = {
 	"lzf.decompress"
 };
 
+#if PHP_VERSION_ID < 70200
 static php_stream_filter *lzf_compress_filter_create(const char *filtername, zval *filterparams, int persistent TSRMLS_DC)
+#else
+static php_stream_filter *lzf_compress_filter_create(const char *filtername, zval *filterparams, uint8_t persistent TSRMLS_DC)
+#endif
 {
 	php_lzf_filter_state *inst;
 
@@ -263,7 +267,11 @@ static php_stream_filter *lzf_compress_filter_create(const char *filtername, zva
 	return php_stream_filter_alloc(&lzf_compress_ops, inst, persistent);
 }
 
+#if PHP_VERSION_ID < 70200
 static php_stream_filter *lzf_decompress_filter_create(const char *filtername, zval *filterparams, int persistent TSRMLS_DC)
+#else
+static php_stream_filter *lzf_decompress_filter_create(const char *filtername, zval *filterparams, uint8_t persistent TSRMLS_DC)
+#endif
 {
 	php_lzf_filter_state *inst;
 
